﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

/// <summary>        
/// SmartI/O FET(TROUT0~4) / Relay 테스트
/// SmartX : SmartGPIO
/// 기능 : 외부전원으로 구동하는 장비연동시 온/오프 조작
/// 응용분야 : 외부 AC/DC전원의 스위치용도
/// 항목 : FET - DC할로겐램프(12V10W)
///            - 냉온소자(FALC1-00705T150)
///            - DC모터
///        Relay S/W - AC할로겐램프(220V,50W)
/// </summary>

namespace TechNote55_SmartIO_Output_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // 현재 Form을 MainForm으로 설정합니다.
            smartForm1.MainForm = this;

            // GPIO Port를 A로 설정
            smartGPIO1.PortSelect = SmartX.SmartGPIO.PORTID.PORTA;
            // PortA의 방향을 ALL OUTPUT으로 설정
            smartGPIO1.PortDirs = 255;
            // PortA의 상태를 ALL Low로 설정
            smartGPIO1.PortDatas = 0;

            // 이미지를 SmartPictureBox의 ImageList에 저장
            pbDCLamp.AddImageList(Resource1.Lamp_0);
            pbDCLamp.AddImageList(Resource1.Lamp_1);
            pbDCLamp.DrawNext(0);

            pbColdHot.AddImageList(Resource1.ColdHot_0);
            pbColdHot.AddImageList(Resource1.ColdHot_1);
            pbColdHot.DrawNext(0);

            pbDCMortor.AddImageList(Resource1.Motor_0);
            pbDCMortor.AddImageList(Resource1.Motor_1);
            pbDCMortor.DrawNext(0);

            pbACLamp.AddImageList(Resource1.Lamp_0);
            pbACLamp.AddImageList(Resource1.Lamp_1);
            pbACLamp.DrawNext(0);
        }

        /// <summary>
        /// FET(TROUT1~4) Control - (PORTA 0~3)
        /// </summary>

        // FET(TROUT1) DC할로겐램프 ON/OFF 제어
        private void btnDCLampCtrl_Click(object sender, EventArgs e)
        {
            // DC 할로겐램프 ON
            if (btnDCLampCtrl.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
            {
                smartGPIO1.Data0 = SmartX.SmartGPIO.PinStatus.High;
                pbDCLamp.DrawNext(1);
            }
            // DC 할로겐램프 OFF
            else
            {
                smartGPIO1.Data0 = SmartX.SmartGPIO.PinStatus.Low;
                pbDCLamp.DrawNext(0);
            }
        }

        // FET(TROUT2) 냉온소자 ON/OFF 제어
        private void btnColdHotCtrl_Click(object sender, EventArgs e)
        {
            // 냉온소자 ON
            if (btnColdHotCtrl.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
            {
                smartGPIO1.Data1 = SmartX.SmartGPIO.PinStatus.High;
                pbColdHot.DrawNext(1);
            }
            // 냉온소자 OFF
            else
            {
                smartGPIO1.Data1 = SmartX.SmartGPIO.PinStatus.Low;
                pbColdHot.DrawNext(0);
            }
        }

        // FET(TROUT3) DC모터 ON/OFF 제어
        private void btnDCMortorCtrl_Click(object sender, EventArgs e)
        {
            // DC모터 ON
            if (btnDCMortorCtrl.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
            {
                smartGPIO1.Data2 = SmartX.SmartGPIO.PinStatus.High;
                pbDCMortor.IncrementType = SmartX.SmartPictureBox.IncrementTypes.RingCount;
                pbDCMortor.Play();
            }
            // DC모터 OFF
            else
            {
                smartGPIO1.Data2 = SmartX.SmartGPIO.PinStatus.Low;
                pbDCMortor.Stop();
            }
        }

        /// <summary>
        /// Relay S/W(RY_SW1~4) Control - (PORTA 7~4)
        /// </summary>

        // Relay S/W AC할로겐램프 ON/OFF 제어
        private void btnACLampCtrl_Click(object sender, EventArgs e)
        {
            // AC 할로겐램프 ON
            if (btnACLampCtrl.ButtonStatus == SmartX.SmartButton.BUTSTATUS.DOWN)
            {
                smartGPIO1.Data4 = SmartX.SmartGPIO.PinStatus.High;
                pbACLamp.DrawNext(1);
            }
            // AC할로겐램프 OFF
            else
            {
                smartGPIO1.Data4 = SmartX.SmartGPIO.PinStatus.Low;
                pbACLamp.DrawNext(0);
            }
        }
    }
}